==> geant4.10.00.p04.tar.gz: geant4.10.00.p04/examples/.doxygen/Doxymodules_basic.h <==
// $Id: Doxymodules_basic.h 76473 2013-11-11 10:35:14Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_basic.h
/// \brief The page that defines the basic examples modules 


/** @defgroup basic basic
 *  Basic examples classes
 *  @{
 */
/** @} */

/** @defgroup B1 B1
 *  Example B1 
 *  @ingroup basic
 *  @{
 */

  class B1ActionInitialization{};
  class B1DetectorConstruction{};
  class B1EventAction{};
  class B1PrimaryGeneratorAction{};
  class B1Run{};
  class B1RunAction{};
  class B1SteppingAction{};

/** @} */

/** @defgroup B2 B2
 *  Example B2 
 *  @ingroup basic
 *  @{
 */

/** @defgroup B2a B2a
 *  Example B2a 
 *  @ingroup B2
 *  @{
 */

  class B2ActionInitialization{};
  class B2aDetectorConstruction{};
  class B2aDetectorMessenger{};
  class B2EventAction{};
  class B2PrimaryGeneratorAction{};
  class B2RunAction{};
  class B2TrackerHit{};
  class B2TrackerSD{};

/** @} */

/** @defgroup B2b B2b
 *  Example B2b 
 *  @ingroup B2
 *  @{
 */

  class B2ActionInitialization{};
  class B2bChamberParameterisation{};
  class B2bDetectorConstruction{};
  class B2bDetectorMessenger{};
  class B2EventAction{};
  class B2PrimaryGeneratorAction{};
  class B2RunAction{};
  class B2TrackerHit{};
  class B2TrackerSD{};

/** @} */

/** @} */

/** @defgroup B3 B3
 *  Example B3 
 *  @ingroup basic
 *  @{
 */

  class B3ActionInitialization{};
  class B3DetectorConstruction{};
  class B3PhysicsList{};
  class B3PrimaryGeneratorAction{};
  class B3Run{};
  class B3RunAction{};
  class B3StackingAction{};

/** @} */

/** @defgroup B4 B4
 *  Example B4 
 *  @ingroup basic
 *  @{
 */
/** @} */

/** @defgroup B4a B4a
 *  Example B4a 
 *  @ingroup B4
 *  @{
 */

  class B4aActionInitialization{};
  class B4aEventAction{};
  class B4aSteppingAction{};
  class B4DetectorConstruction{};
  class B4PrimaryGeneratorAction{};
  class B4RunAction{};

/** @} */

/** @} */
/** @defgroup B4b B4b
 *  Example B4b 
 *  @ingroup B4
 *  @{
 */

  class B4bActionInitialization{};
  class B4bEventAction{};
  class B4bRunAction{};
  class B4bRunData{};
  class B4bSteppingAction{};
  class B4DetectorConstruction{};
  class B4PrimaryGeneratorAction{};

/** @} */

/** @defgroup B4c B4c
 *  Example B4c 
 *  @ingroup B4
 *  @{
 */

  class B4cActionInitialization{};
  class B4cCalorHit{};
  class B4cCalorimeterSD{};
  class B4cDetectorConstruction{};
  class B4cEventAction{};
  class B4PrimaryGeneratorAction{};
  class B4RunAction{};

/** @} */

/** @} */
/** @defgroup B4d B4d
 *  Example B4d 
 *  @ingroup B4
 *  @{
 */

  class B4dActionInitialization{};
  class B4dDetectorConstruction{};
  class B4dEventAction{};
  class B4PrimaryGeneratorAction{};
  class B4RunAction{};

/** @} */

/** @} */

/** @defgroup B5 B5
 *  Example B5 
 *  @ingroup basic
 *  @{
 */

  class B5ActionInitialization{};
  class B5CellParameterisation{};
  class B5DetectorConstruction{};
  class B5DriftChamberHit{};
  class B5DriftChamberSD{};
  class B5EmCalorimeterHit{};
  class B5EmCalorimeterSD{};
  class B5EventAction{};
  class B5HadCalorimeterHit{};
  class B5HadCalorimeterSD{};
  class B5HodoscopeHit{};
  class B5HodoscopeSD{};
  class B5MagneticField{};
  class B5PrimaryGeneratorAction{};
  class B5RunAction{};

/** @} */

/** @} */

==> geant4.10.03.p03.tar.gz: geant4.10.03.p03/examples/.doxygen/Doxymodules_basic.h <==
// $Id: Doxymodules_basic.h 94561 2015-11-24 09:17:12Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_basic.h
/// \brief The page that defines the basic examples modules 


/** @defgroup basic basic
 *  Basic examples classes
 *  @{
 */
/** @} */

/** @defgroup B1 B1
 *  Example B1 
 *  @ingroup basic
 *  @{
 */

  class B1ActionInitialization{};
  class B1DetectorConstruction{};
  class B1EventAction{};
  class B1PrimaryGeneratorAction{};
  class B1Run{};
  class B1RunAction{};
  class B1SteppingAction{};

/** @} */

/** @defgroup B2 B2
 *  Example B2 
 *  @ingroup basic
 *  @{
 */

/** @defgroup B2a B2a
 *  Example B2a 
 *  @ingroup B2
 *  @{
 */

  class B2ActionInitialization{};
  class B2aDetectorConstruction{};
  class B2aDetectorMessenger{};
  class B2EventAction{};
  class B2PrimaryGeneratorAction{};
  class B2RunAction{};
  class B2TrackerHit{};
  class B2TrackerSD{};

/** @} */

/** @defgroup B2b B2b
 *  Example B2b 
 *  @ingroup B2
 *  @{
 */

  class B2ActionInitialization{};
  class B2bChamberParameterisation{};
  class B2bDetectorConstruction{};
  class B2bDetectorMessenger{};
  class B2EventAction{};
  class B2PrimaryGeneratorAction{};
  class B2RunAction{};
  class B2TrackerHit{};
  class B2TrackerSD{};

/** @} */

/** @} */

/** @defgroup B3 B3
 *  Example B3 
 *  @ingroup basic
 *  @{
 */

/** @defgroup B3a B3a
 *  Example B3a 
 *  @ingroup B3
 *  @{
 */

  class B3aActionInitialization{};
  class B3aEventAction{};
  class B3aRunAction{};
  class B3DetectorConstruction{};
  class B3PhysicsList{};
  class B3PrimaryGeneratorAction{};
  class B3StackingAction{};

/** @} */

/** @defgroup B3b B3b
 *  Example B3b
 *  @ingroup B3
 *  @{
 */

  class B3bActionInitialization{};
  class B3bRun{};
  class B3bRunAction{};
  class B3DetectorConstruction{};
  class B3PhysicsList{};
  class B3PrimaryGeneratorAction{};
  class B3StackingAction{};

/** @} */

/** @} */

/** @defgroup B4 B4
 *  Example B4 
 *  @ingroup basic
 *  @{
 */
/** @} */

/** @defgroup B4a B4a
 *  Example B4a 
 *  @ingroup B4
 *  @{
 */

  class B4aActionInitialization{};
  class B4aEventAction{};
  class B4aSteppingAction{};
  class B4DetectorConstruction{};
  class B4PrimaryGeneratorAction{};
  class B4RunAction{};

/** @} */

/** @} */
/** @defgroup B4b B4b
 *  Example B4b 
 *  @ingroup B4
 *  @{
 */

  class B4bActionInitialization{};
  class B4bEventAction{};
  class B4bRunAction{};
  class B4bRunData{};
  class B4bSteppingAction{};
  class B4DetectorConstruction{};
  class B4PrimaryGeneratorAction{};

/** @} */

/** @defgroup B4c B4c
 *  Example B4c 
 *  @ingroup B4
 *  @{
 */

  class B4cActionInitialization{};
  class B4cCalorHit{};
  class B4cCalorimeterSD{};
  class B4cDetectorConstruction{};
  class B4cEventAction{};
  class B4PrimaryGeneratorAction{};
  class B4RunAction{};

/** @} */

/** @} */
/** @defgroup B4d B4d
 *  Example B4d 
 *  @ingroup B4
 *  @{
 */

  class B4dActionInitialization{};
  class B4dDetectorConstruction{};
  class B4dEventAction{};
  class B4PrimaryGeneratorAction{};
  class B4RunAction{};

/** @} */

/** @} */

/** @defgroup B5 B5
 *  Example B5 
 *  @ingroup basic
 *  @{
 */

  class B5ActionInitialization{};
  class B5CellParameterisation{};
  class B5DetectorConstruction{};
  class B5DriftChamberHit{};
  class B5DriftChamberSD{};
  class B5EmCalorimeterHit{};
  class B5EmCalorimeterSD{};
  class B5EventAction{};
  class B5HadCalorimeterHit{};
  class B5HadCalorimeterSD{};
  class B5HodoscopeHit{};
  class B5HodoscopeSD{};
  class B5MagneticField{};
  class B5PrimaryGeneratorAction{};
  class B5RunAction{};

/** @} */

/** @} */
